const { openBrowser, client, closeBrowser, $, goto, evaluate , attach, click, to, fileField, dropDown} = require('taiko');
const assert = require("assert");
const URL = 'http://solution-container:8080';


beforeSuite(async () => {
	await openBrowser({
		headless: true,
		args: [
			'--disable-gpu',
			'--disable-dev-shm-usage',
			'--disable-setuid-sandbox',
			'--no-first-run',
			'--no-sandbox',
			'--no-zygote',
			'--observe'
		]
	});
});

afterSuite(async () => {
	await closeBrowser();
});

async function attachFile(){
  	  await attach('data/Ticketsfile-1.csv',to(fileField({'id':'ticketFile'})));
	  await dropDown('Select Challenge Type').select('Type 1');
	  await click('Read Files & Display Result');
}

async function attachFile2(){
  	  await attach('data/Ticketsfile-2.csv',to(fileField({'id':'ticketFile'})));
	  await dropDown('Select Challenge Type').select('Type 2');
	  await click('Read Files & Display Result');
	
}


step('There should be a file input field rendered', async function() {
	await goto(URL);
	await attachFile();
	const button = $(`input`);
	const buttonText = await evaluate(button, element => element.innerText);
	assert.equal(isNaN(buttonText), false);
});

step('Verify file input is clickable', async function() {
	try {
	await attachFile();
	 } catch (e) {
	   console.error(e);
	   assert(false);
	 } finally {
	   assert(true);
	 }
});

step('Verify dropdown exists', async function() {
	await goto(URL);
	const drop = $((selector) => document.getElementById(selector), { args: 'challengeType' });
	const contents = await evaluate(drop, elem => elem.innerText);
	assert.equal(contents === null || contents === '',false);
});

step('Verify table field is rendered', async function() {
	try {
	  await goto(URL); 
	  await attachFile();
	  const table = $((selector) => document.getElementById(selector), { args: 'resultsTable' });
  	  const tableText = await evaluate(table, element => element.outerHTML);
	  assert.equal(tableText.length===0, false);
	 } catch (e) {
	   console.error(e);
	   assert(false);
	 } finally {
	   assert(true);
	 }
});

step('Verify download button is rendered', async function() {
	await goto(URL);
	const button = $((selector) => document.getElementById(selector), { args: 'btnSave' });
	const buttonText = await evaluate(button, element => element.innerText);
	assert.equal(isNaN(buttonText), false);
});

step('Verify download button is clickable', async function() {
	await goto(URL);
	const button = $((selector) => document.getElementById(selector), { args: 'btnSave' });
	try {
	   await click(button);
	 } catch (e) {
	   console.error(e);
	   assert(false);
	 } finally {
	   assert(true);
	 }
});

step('Verify results table has contents', async function() {
	try {
	  await goto(URL); 
	  await attachFile();
	  const table = $((selector) => document.getElementById(selector), { args: 'resultsTable' });
  	  const tableText = await evaluate(table, element => element.innerHTML);
	  assert.equal(tableText.length===0, false);
	 } catch (e) {
	   console.error(e);
	   assert(false);
	 } finally {
	   assert(true);
	 }
});
